# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiServiceIntegrationArgs', 'ApiServiceIntegration']

@pulumi.input_type
class ApiServiceIntegrationArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]] = None):
        """
        The set of arguments for constructing a ApiServiceIntegration resource.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        :param pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        """
        pulumi.set(__self__, "type", type)
        if granted_scopes is not None:
            pulumi.set(__self__, "granted_scopes", granted_scopes)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]:
        """
        The list of Okta management scopes granted to the API Service Integration instance.
        """
        return pulumi.get(self, "granted_scopes")

    @granted_scopes.setter
    def granted_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]):
        pulumi.set(self, "granted_scopes", value)


@pulumi.input_type
class _ApiServiceIntegrationState:
    def __init__(__self__, *,
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApiServiceIntegration resources.
        :param pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        :param pulumi.Input[_builtins.str] name: The name of the API service integration that corresponds with the type property.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        if granted_scopes is not None:
            pulumi.set(__self__, "granted_scopes", granted_scopes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]:
        """
        The list of Okta management scopes granted to the API Service Integration instance.
        """
        return pulumi.get(self, "granted_scopes")

    @granted_scopes.setter
    def granted_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApiServiceIntegrationGrantedScopeArgs']]]]):
        pulumi.set(self, "granted_scopes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the API service integration that corresponds with the type property.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/apiServiceIntegration:ApiServiceIntegration")
class ApiServiceIntegration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## ---

        page_title: "Resource: ApiServiceIntegration"
        description: |-

        ***

        # Resource: ApiServiceIntegration

        This API provides operations to manage API service integration instances in your org.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiServiceIntegration("example",
            type="anzennaapiservice",
            granted_scopes=[
                {
                    "scope": "okta.users.read",
                },
                {
                    "scope": "okta.groups.read",
                },
                {
                    "scope": "okta.logs.read",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/apiServiceIntegration:ApiServiceIntegration example <api_service_integration_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiServiceIntegrationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## ---

        page_title: "Resource: ApiServiceIntegration"
        description: |-

        ***

        # Resource: ApiServiceIntegration

        This API provides operations to manage API service integration instances in your org.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.ApiServiceIntegration("example",
            type="anzennaapiservice",
            granted_scopes=[
                {
                    "scope": "okta.users.read",
                },
                {
                    "scope": "okta.groups.read",
                },
                {
                    "scope": "okta.logs.read",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/apiServiceIntegration:ApiServiceIntegration example <api_service_integration_id>
        ```

        :param str resource_name: The name of the resource.
        :param ApiServiceIntegrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiServiceIntegrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiServiceIntegrationArgs.__new__(ApiServiceIntegrationArgs)

            __props__.__dict__["granted_scopes"] = granted_scopes
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["name"] = None
        super(ApiServiceIntegration, __self__).__init__(
            'okta:index/apiServiceIntegration:ApiServiceIntegration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            granted_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApiServiceIntegration':
        """
        Get an existing ApiServiceIntegration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApiServiceIntegrationGrantedScopeArgs', 'ApiServiceIntegrationGrantedScopeArgsDict']]]] granted_scopes: The list of Okta management scopes granted to the API Service Integration instance.
        :param pulumi.Input[_builtins.str] name: The name of the API service integration that corresponds with the type property.
        :param pulumi.Input[_builtins.str] type: The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiServiceIntegrationState.__new__(_ApiServiceIntegrationState)

        __props__.__dict__["granted_scopes"] = granted_scopes
        __props__.__dict__["name"] = name
        __props__.__dict__["type"] = type
        return ApiServiceIntegration(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> pulumi.Output[Optional[Sequence['outputs.ApiServiceIntegrationGrantedScope']]]:
        """
        The list of Okta management scopes granted to the API Service Integration instance.
        """
        return pulumi.get(self, "granted_scopes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the API service integration that corresponds with the type property.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DeviceAssuranceAndroidArgs', 'DeviceAssuranceAndroid']

@pulumi.input_type
class DeviceAssuranceAndroidArgs:
    def __init__(__self__, *,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 jailbreak: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a DeviceAssuranceAndroid resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `FULL`, `USER`
        :param pulumi.Input[_builtins.bool] jailbreak: Is the device jailbroken in the device assurance policy.
        :param pulumi.Input[_builtins.str] name: Policy device assurance name
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Indicates if the device contains a secure hardware functionality
        """
        if disk_encryption_types is not None:
            pulumi.set(__self__, "disk_encryption_types", disk_encryption_types)
        if jailbreak is not None:
            pulumi.set(__self__, "jailbreak", jailbreak)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if os_version is not None:
            pulumi.set(__self__, "os_version", os_version)
        if screenlock_types is not None:
            pulumi.set(__self__, "screenlock_types", screenlock_types)
        if secure_hardware_present is not None:
            pulumi.set(__self__, "secure_hardware_present", secure_hardware_present)

    @_builtins.property
    @pulumi.getter(name="diskEncryptionTypes")
    def disk_encryption_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of disk encryption type, can be `FULL`, `USER`
        """
        return pulumi.get(self, "disk_encryption_types")

    @disk_encryption_types.setter
    def disk_encryption_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "disk_encryption_types", value)

    @_builtins.property
    @pulumi.getter
    def jailbreak(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is the device jailbroken in the device assurance policy.
        """
        return pulumi.get(self, "jailbreak")

    @jailbreak.setter
    def jailbreak(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "jailbreak", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy device assurance name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @os_version.setter
    def os_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "os_version", value)

    @_builtins.property
    @pulumi.getter(name="screenlockTypes")
    def screenlock_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_types")

    @screenlock_types.setter
    def screenlock_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "screenlock_types", value)

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the device contains a secure hardware functionality
        """
        return pulumi.get(self, "secure_hardware_present")

    @secure_hardware_present.setter
    def secure_hardware_present(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "secure_hardware_present", value)


@pulumi.input_type
class _DeviceAssuranceAndroidState:
    def __init__(__self__, *,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 created_date: Optional[pulumi.Input[_builtins.str]] = None,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 jailbreak: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_update: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 platform: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering DeviceAssuranceAndroid resources.
        :param pulumi.Input[_builtins.str] created_by: Created by
        :param pulumi.Input[_builtins.str] created_date: Created date
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `FULL`, `USER`
        :param pulumi.Input[_builtins.bool] jailbreak: Is the device jailbroken in the device assurance policy.
        :param pulumi.Input[_builtins.str] last_update: Last update
        :param pulumi.Input[_builtins.str] last_updated_by: Last updated by
        :param pulumi.Input[_builtins.str] name: Policy device assurance name
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[_builtins.str] platform: Policy device assurance platform
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Indicates if the device contains a secure hardware functionality
        """
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if created_date is not None:
            pulumi.set(__self__, "created_date", created_date)
        if disk_encryption_types is not None:
            pulumi.set(__self__, "disk_encryption_types", disk_encryption_types)
        if jailbreak is not None:
            pulumi.set(__self__, "jailbreak", jailbreak)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if os_version is not None:
            pulumi.set(__self__, "os_version", os_version)
        if platform is not None:
            pulumi.set(__self__, "platform", platform)
        if screenlock_types is not None:
            pulumi.set(__self__, "screenlock_types", screenlock_types)
        if secure_hardware_present is not None:
            pulumi.set(__self__, "secure_hardware_present", secure_hardware_present)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created by
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created date
        """
        return pulumi.get(self, "created_date")

    @created_date.setter
    def created_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_date", value)

    @_builtins.property
    @pulumi.getter(name="diskEncryptionTypes")
    def disk_encryption_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of disk encryption type, can be `FULL`, `USER`
        """
        return pulumi.get(self, "disk_encryption_types")

    @disk_encryption_types.setter
    def disk_encryption_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "disk_encryption_types", value)

    @_builtins.property
    @pulumi.getter
    def jailbreak(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Is the device jailbroken in the device assurance policy.
        """
        return pulumi.get(self, "jailbreak")

    @jailbreak.setter
    def jailbreak(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "jailbreak", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last update
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_update", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last updated by
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy device assurance name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @os_version.setter
    def os_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "os_version", value)

    @_builtins.property
    @pulumi.getter
    def platform(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Policy device assurance platform
        """
        return pulumi.get(self, "platform")

    @platform.setter
    def platform(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "platform", value)

    @_builtins.property
    @pulumi.getter(name="screenlockTypes")
    def screenlock_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_types")

    @screenlock_types.setter
    def screenlock_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "screenlock_types", value)

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if the device contains a secure hardware functionality
        """
        return pulumi.get(self, "secure_hardware_present")

    @secure_hardware_present.setter
    def secure_hardware_present(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "secure_hardware_present", value)


@pulumi.type_token("okta:policy/deviceAssuranceAndroid:DeviceAssuranceAndroid")
class DeviceAssuranceAndroid(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 jailbreak: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages a device assurance policy for android.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        example = okta.policy.DeviceAssuranceAndroid("example",
            name="example",
            os_version="12",
            disk_encryption_types=std.index.toset(input=[
                "FULL",
                "USER",
            ])["result"],
            jailbreak=False,
            secure_hardware_present=True,
            screenlock_types=std.index.toset(input=["BIOMETRIC"])["result"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:policy/deviceAssuranceAndroid:DeviceAssuranceAndroid example <device_assurance_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `FULL`, `USER`
        :param pulumi.Input[_builtins.bool] jailbreak: Is the device jailbroken in the device assurance policy.
        :param pulumi.Input[_builtins.str] name: Policy device assurance name
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Indicates if the device contains a secure hardware functionality
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DeviceAssuranceAndroidArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a device assurance policy for android.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta
        import pulumi_std as std

        example = okta.policy.DeviceAssuranceAndroid("example",
            name="example",
            os_version="12",
            disk_encryption_types=std.index.toset(input=[
                "FULL",
                "USER",
            ])["result"],
            jailbreak=False,
            secure_hardware_present=True,
            screenlock_types=std.index.toset(input=["BIOMETRIC"])["result"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:policy/deviceAssuranceAndroid:DeviceAssuranceAndroid example <device_assurance_id>
        ```

        :param str resource_name: The name of the resource.
        :param DeviceAssuranceAndroidArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceAssuranceAndroidArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 jailbreak: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 os_version: Optional[pulumi.Input[_builtins.str]] = None,
                 screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceAssuranceAndroidArgs.__new__(DeviceAssuranceAndroidArgs)

            __props__.__dict__["disk_encryption_types"] = disk_encryption_types
            __props__.__dict__["jailbreak"] = jailbreak
            __props__.__dict__["name"] = name
            __props__.__dict__["os_version"] = os_version
            __props__.__dict__["screenlock_types"] = screenlock_types
            __props__.__dict__["secure_hardware_present"] = secure_hardware_present
            __props__.__dict__["created_by"] = None
            __props__.__dict__["created_date"] = None
            __props__.__dict__["last_update"] = None
            __props__.__dict__["last_updated_by"] = None
            __props__.__dict__["platform"] = None
        super(DeviceAssuranceAndroid, __self__).__init__(
            'okta:policy/deviceAssuranceAndroid:DeviceAssuranceAndroid',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            created_date: Optional[pulumi.Input[_builtins.str]] = None,
            disk_encryption_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            jailbreak: Optional[pulumi.Input[_builtins.bool]] = None,
            last_update: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            os_version: Optional[pulumi.Input[_builtins.str]] = None,
            platform: Optional[pulumi.Input[_builtins.str]] = None,
            screenlock_types: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            secure_hardware_present: Optional[pulumi.Input[_builtins.bool]] = None) -> 'DeviceAssuranceAndroid':
        """
        Get an existing DeviceAssuranceAndroid resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_by: Created by
        :param pulumi.Input[_builtins.str] created_date: Created date
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] disk_encryption_types: List of disk encryption type, can be `FULL`, `USER`
        :param pulumi.Input[_builtins.bool] jailbreak: Is the device jailbroken in the device assurance policy.
        :param pulumi.Input[_builtins.str] last_update: Last update
        :param pulumi.Input[_builtins.str] last_updated_by: Last updated by
        :param pulumi.Input[_builtins.str] name: Policy device assurance name
        :param pulumi.Input[_builtins.str] os_version: Minimum os version of the device in the device assurance policy.
        :param pulumi.Input[_builtins.str] platform: Policy device assurance platform
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] screenlock_types: List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        :param pulumi.Input[_builtins.bool] secure_hardware_present: Indicates if the device contains a secure hardware functionality
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceAssuranceAndroidState.__new__(_DeviceAssuranceAndroidState)

        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["created_date"] = created_date
        __props__.__dict__["disk_encryption_types"] = disk_encryption_types
        __props__.__dict__["jailbreak"] = jailbreak
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["name"] = name
        __props__.__dict__["os_version"] = os_version
        __props__.__dict__["platform"] = platform
        __props__.__dict__["screenlock_types"] = screenlock_types
        __props__.__dict__["secure_hardware_present"] = secure_hardware_present
        return DeviceAssuranceAndroid(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        Created by
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="createdDate")
    def created_date(self) -> pulumi.Output[_builtins.str]:
        """
        Created date
        """
        return pulumi.get(self, "created_date")

    @_builtins.property
    @pulumi.getter(name="diskEncryptionTypes")
    def disk_encryption_types(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of disk encryption type, can be `FULL`, `USER`
        """
        return pulumi.get(self, "disk_encryption_types")

    @_builtins.property
    @pulumi.getter
    def jailbreak(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Is the device jailbroken in the device assurance policy.
        """
        return pulumi.get(self, "jailbreak")

    @_builtins.property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[_builtins.str]:
        """
        Last update
        """
        return pulumi.get(self, "last_update")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        Last updated by
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Policy device assurance name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Minimum os version of the device in the device assurance policy.
        """
        return pulumi.get(self, "os_version")

    @_builtins.property
    @pulumi.getter
    def platform(self) -> pulumi.Output[_builtins.str]:
        """
        Policy device assurance platform
        """
        return pulumi.get(self, "platform")

    @_builtins.property
    @pulumi.getter(name="screenlockTypes")
    def screenlock_types(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of screenlock type, can be `BIOMETRIC` or `BIOMETRIC, PASSCODE`
        """
        return pulumi.get(self, "screenlock_types")

    @_builtins.property
    @pulumi.getter(name="secureHardwarePresent")
    def secure_hardware_present(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if the device contains a secure hardware functionality
        """
        return pulumi.get(self, "secure_hardware_present")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetEmailCustomizationResult',
    'AwaitableGetEmailCustomizationResult',
    'get_email_customization',
    'get_email_customization_output',
]

@pulumi.output_type
class GetEmailCustomizationResult:
    """
    A collection of values returned by getEmailCustomization.
    """
    def __init__(__self__, body=None, brand_id=None, customization_id=None, id=None, is_default=None, language=None, links=None, subject=None, template_name=None):
        if body and not isinstance(body, str):
            raise TypeError("Expected argument 'body' to be a str")
        pulumi.set(__self__, "body", body)
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if customization_id and not isinstance(customization_id, str):
            raise TypeError("Expected argument 'customization_id' to be a str")
        pulumi.set(__self__, "customization_id", customization_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_default and not isinstance(is_default, bool):
            raise TypeError("Expected argument 'is_default' to be a bool")
        pulumi.set(__self__, "is_default", is_default)
        if language and not isinstance(language, str):
            raise TypeError("Expected argument 'language' to be a str")
        pulumi.set(__self__, "language", language)
        if links and not isinstance(links, str):
            raise TypeError("Expected argument 'links' to be a str")
        pulumi.set(__self__, "links", links)
        if subject and not isinstance(subject, str):
            raise TypeError("Expected argument 'subject' to be a str")
        pulumi.set(__self__, "subject", subject)
        if template_name and not isinstance(template_name, str):
            raise TypeError("Expected argument 'template_name' to be a str")
        pulumi.set(__self__, "template_name", template_name)

    @_builtins.property
    @pulumi.getter
    def body(self) -> _builtins.str:
        """
        The body of the customization
        """
        return pulumi.get(self, "body")

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> _builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="customizationId")
    def customization_id(self) -> _builtins.str:
        """
        The ID of the customization
        """
        return pulumi.get(self, "customization_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the customization
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> _builtins.bool:
        """
        Whether the customization is the default
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def language(self) -> _builtins.str:
        """
        The language supported by the customization
        """
        return pulumi.get(self, "language")

    @_builtins.property
    @pulumi.getter
    def links(self) -> _builtins.str:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the email template
        """
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def subject(self) -> _builtins.str:
        """
        The subject of the customization
        """
        return pulumi.get(self, "subject")

    @_builtins.property
    @pulumi.getter(name="templateName")
    def template_name(self) -> _builtins.str:
        """
        Template Name
        """
        return pulumi.get(self, "template_name")


class AwaitableGetEmailCustomizationResult(GetEmailCustomizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEmailCustomizationResult(
            body=self.body,
            brand_id=self.brand_id,
            customization_id=self.customization_id,
            id=self.id,
            is_default=self.is_default,
            language=self.language,
            links=self.links,
            subject=self.subject,
            template_name=self.template_name)


def get_email_customization(brand_id: Optional[_builtins.str] = None,
                            customization_id: Optional[_builtins.str] = None,
                            template_name: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEmailCustomizationResult:
    """
    Get the email customization of an email template belonging to a brand in an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    forgot_password = okta.get_email_customizations(brand_id=test.brands[0].id,
        template_name="ForgotPassword")
    forgot_password_en = okta.get_email_customization(brand_id=test.brands[0].id,
        template_name="ForgotPassword",
        customization_id=forgot_password.email_customizations[0].id)
    ```


    :param _builtins.str brand_id: Brand ID
    :param _builtins.str customization_id: The ID of the customization
    :param _builtins.str template_name: Template Name
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['customizationId'] = customization_id
    __args__['templateName'] = template_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getEmailCustomization:getEmailCustomization', __args__, opts=opts, typ=GetEmailCustomizationResult).value

    return AwaitableGetEmailCustomizationResult(
        body=pulumi.get(__ret__, 'body'),
        brand_id=pulumi.get(__ret__, 'brand_id'),
        customization_id=pulumi.get(__ret__, 'customization_id'),
        id=pulumi.get(__ret__, 'id'),
        is_default=pulumi.get(__ret__, 'is_default'),
        language=pulumi.get(__ret__, 'language'),
        links=pulumi.get(__ret__, 'links'),
        subject=pulumi.get(__ret__, 'subject'),
        template_name=pulumi.get(__ret__, 'template_name'))
def get_email_customization_output(brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   customization_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   template_name: Optional[pulumi.Input[_builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEmailCustomizationResult]:
    """
    Get the email customization of an email template belonging to a brand in an Okta organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    forgot_password = okta.get_email_customizations(brand_id=test.brands[0].id,
        template_name="ForgotPassword")
    forgot_password_en = okta.get_email_customization(brand_id=test.brands[0].id,
        template_name="ForgotPassword",
        customization_id=forgot_password.email_customizations[0].id)
    ```


    :param _builtins.str brand_id: Brand ID
    :param _builtins.str customization_id: The ID of the customization
    :param _builtins.str template_name: Template Name
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['customizationId'] = customization_id
    __args__['templateName'] = template_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getEmailCustomization:getEmailCustomization', __args__, opts=opts, typ=GetEmailCustomizationResult)
    return __ret__.apply(lambda __response__: GetEmailCustomizationResult(
        body=pulumi.get(__response__, 'body'),
        brand_id=pulumi.get(__response__, 'brand_id'),
        customization_id=pulumi.get(__response__, 'customization_id'),
        id=pulumi.get(__response__, 'id'),
        is_default=pulumi.get(__response__, 'is_default'),
        language=pulumi.get(__response__, 'language'),
        links=pulumi.get(__response__, 'links'),
        subject=pulumi.get(__response__, 'subject'),
        template_name=pulumi.get(__response__, 'template_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('okta')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def access_token(self) -> Optional[str]:
        """
        Bearer token granting privileges to Okta API.
        """
        return __config__.get('accessToken')

    @_builtins.property
    def api_token(self) -> Optional[str]:
        """
        API Token granting privileges to Okta API.
        """
        return __config__.get('apiToken')

    @_builtins.property
    def backoff(self) -> Optional[bool]:
        """
        Use exponential back off strategy for rate limits.
        """
        return __config__.get_bool('backoff')

    @_builtins.property
    def base_url(self) -> Optional[str]:
        """
        The Okta url. (Use 'oktapreview.com' for Okta testing)
        """
        return __config__.get('baseUrl')

    @_builtins.property
    def client_id(self) -> Optional[str]:
        """
        API Token granting privileges to Okta API.
        """
        return __config__.get('clientId')

    @_builtins.property
    def http_proxy(self) -> Optional[str]:
        """
        Alternate HTTP proxy of scheme://hostname or scheme://hostname:port format
        """
        return __config__.get('httpProxy')

    @_builtins.property
    def log_level(self) -> Optional[int]:
        """
        providers log level. Minimum is 1 (TRACE), and maximum is 5 (ERROR)
        """
        return __config__.get_int('logLevel')

    @_builtins.property
    def max_api_capacity(self) -> Optional[int]:
        """
        Sets what percentage of capacity the provider can use of the total rate limit capacity while making calls to the Okta management API endpoints. Okta API operates in one minute buckets. See Okta Management API Rate Limits: https://developer.okta.com/docs/reference/rl-global-mgmt/
        """
        return __config__.get_int('maxApiCapacity')

    @_builtins.property
    def max_retries(self) -> Optional[int]:
        """
        maximum number of retries to attempt before erroring out.
        """
        return __config__.get_int('maxRetries')

    @_builtins.property
    def max_wait_seconds(self) -> Optional[int]:
        """
        maximum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
        """
        return __config__.get_int('maxWaitSeconds')

    @_builtins.property
    def min_wait_seconds(self) -> Optional[int]:
        """
        minimum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
        """
        return __config__.get_int('minWaitSeconds')

    @_builtins.property
    def org_name(self) -> Optional[str]:
        """
        The organization to manage in Okta.
        """
        return __config__.get('orgName')

    @_builtins.property
    def parallelism(self) -> Optional[int]:
        """
        Number of concurrent requests to make within a resource where bulk operations are not possible. Take note of https://developer.okta.com/docs/api/getting_started/rate-limits.
        """
        return __config__.get_int('parallelism')

    @_builtins.property
    def private_key(self) -> Optional[str]:
        """
        API Token granting privileges to Okta API.
        """
        return __config__.get('privateKey')

    @_builtins.property
    def private_key_id(self) -> Optional[str]:
        """
        API Token Id granting privileges to Okta API.
        """
        return __config__.get('privateKeyId')

    @_builtins.property
    def request_timeout(self) -> Optional[int]:
        """
        Timeout for single request (in seconds) which is made to Okta, the default is `0` (means no limit is set). The maximum value can be `300`.
        """
        return __config__.get_int('requestTimeout')

    @_builtins.property
    def scopes(self) -> Optional[str]:
        """
        API Token granting privileges to Okta API.
        """
        return __config__.get('scopes')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetApiServiceIntegrationResult',
    'AwaitableGetApiServiceIntegrationResult',
    'get_api_service_integration',
    'get_api_service_integration_output',
]

@pulumi.output_type
class GetApiServiceIntegrationResult:
    """
    A collection of values returned by getApiServiceIntegration.
    """
    def __init__(__self__, config_guide_url=None, created=None, created_by=None, granted_scopes=None, id=None, name=None, type=None):
        if config_guide_url and not isinstance(config_guide_url, str):
            raise TypeError("Expected argument 'config_guide_url' to be a str")
        pulumi.set(__self__, "config_guide_url", config_guide_url)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if granted_scopes and not isinstance(granted_scopes, list):
            raise TypeError("Expected argument 'granted_scopes' to be a list")
        pulumi.set(__self__, "granted_scopes", granted_scopes)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="configGuideUrl")
    def config_guide_url(self) -> _builtins.str:
        return pulumi.get(self, "config_guide_url")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="grantedScopes")
    def granted_scopes(self) -> Optional[Sequence['outputs.GetApiServiceIntegrationGrantedScopeResult']]:
        return pulumi.get(self, "granted_scopes")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        return pulumi.get(self, "type")


class AwaitableGetApiServiceIntegrationResult(GetApiServiceIntegrationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApiServiceIntegrationResult(
            config_guide_url=self.config_guide_url,
            created=self.created,
            created_by=self.created_by,
            granted_scopes=self.granted_scopes,
            id=self.id,
            name=self.name,
            type=self.type)


def get_api_service_integration(granted_scopes: Optional[Sequence[Union['GetApiServiceIntegrationGrantedScopeArgs', 'GetApiServiceIntegrationGrantedScopeArgsDict']]] = None,
                                id: Optional[_builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApiServiceIntegrationResult:
    """
    Retrieves an API Service Integration instance by id

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_api_service_integration(id="<api_service_integration_id>")
    ```

    ## Required

    - `id` (String) The id of the API Service Integration instance.

    ### Read-Only

    - `config_guide_url` (String) The URL to the API service integration configuration guide.
    - `created` (String) The created timestamp of the API Service Integration instance.
    - `created_at` (String) Timestamp when the API Service Integration instance was created.
    - `granted_scopes` (List of String) The list of Okta management scopes granted to the API Service Integration instance.(see below for nested schema).
    - `name` (String) The name of the API service integration that corresponds with the type property. This is the full name of the API service integration listed in the Okta Integration Network (OIN) catalog.
    - `type` (String) The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name. For example, my_api_log_integration.
    """
    __args__ = dict()
    __args__['grantedScopes'] = granted_scopes
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getApiServiceIntegration:getApiServiceIntegration', __args__, opts=opts, typ=GetApiServiceIntegrationResult).value

    return AwaitableGetApiServiceIntegrationResult(
        config_guide_url=pulumi.get(__ret__, 'config_guide_url'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        granted_scopes=pulumi.get(__ret__, 'granted_scopes'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        type=pulumi.get(__ret__, 'type'))
def get_api_service_integration_output(granted_scopes: Optional[pulumi.Input[Optional[Sequence[Union['GetApiServiceIntegrationGrantedScopeArgs', 'GetApiServiceIntegrationGrantedScopeArgsDict']]]]] = None,
                                       id: Optional[pulumi.Input[_builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApiServiceIntegrationResult]:
    """
    Retrieves an API Service Integration instance by id

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_api_service_integration(id="<api_service_integration_id>")
    ```

    ## Required

    - `id` (String) The id of the API Service Integration instance.

    ### Read-Only

    - `config_guide_url` (String) The URL to the API service integration configuration guide.
    - `created` (String) The created timestamp of the API Service Integration instance.
    - `created_at` (String) Timestamp when the API Service Integration instance was created.
    - `granted_scopes` (List of String) The list of Okta management scopes granted to the API Service Integration instance.(see below for nested schema).
    - `name` (String) The name of the API service integration that corresponds with the type property. This is the full name of the API service integration listed in the Okta Integration Network (OIN) catalog.
    - `type` (String) The type of the API service integration. This string is an underscore-concatenated, lowercased API service integration name. For example, my_api_log_integration.
    """
    __args__ = dict()
    __args__['grantedScopes'] = granted_scopes
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getApiServiceIntegration:getApiServiceIntegration', __args__, opts=opts, typ=GetApiServiceIntegrationResult)
    return __ret__.apply(lambda __response__: GetApiServiceIntegrationResult(
        config_guide_url=pulumi.get(__response__, 'config_guide_url'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        granted_scopes=pulumi.get(__response__, 'granted_scopes'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPushProviderResult',
    'AwaitableGetPushProviderResult',
    'get_push_provider',
    'get_push_provider_output',
]

@pulumi.output_type
class GetPushProviderResult:
    """
    A collection of values returned by getPushProvider.
    """
    def __init__(__self__, configuration=None, id=None, last_updated_date=None, name=None, provider_type=None):
        if configuration and not isinstance(configuration, dict):
            raise TypeError("Expected argument 'configuration' to be a dict")
        pulumi.set(__self__, "configuration", configuration)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated_date and not isinstance(last_updated_date, str):
            raise TypeError("Expected argument 'last_updated_date' to be a str")
        pulumi.set(__self__, "last_updated_date", last_updated_date)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_type and not isinstance(provider_type, str):
            raise TypeError("Expected argument 'provider_type' to be a str")
        pulumi.set(__self__, "provider_type", provider_type)

    @_builtins.property
    @pulumi.getter
    def configuration(self) -> Optional['outputs.GetPushProviderConfigurationResult']:
        """
        Configuration details for the push provider. The structure depends on the provider type.
        """
        return pulumi.get(self, "configuration")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the push provider to retrieve.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedDate")
    def last_updated_date(self) -> _builtins.str:
        """
        Timestamp when the push provider was last modified.
        """
        return pulumi.get(self, "last_updated_date")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The display name of the push provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> _builtins.str:
        """
        The type of push provider. Values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        return pulumi.get(self, "provider_type")


class AwaitableGetPushProviderResult(GetPushProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPushProviderResult(
            configuration=self.configuration,
            id=self.id,
            last_updated_date=self.last_updated_date,
            name=self.name,
            provider_type=self.provider_type)


def get_push_provider(configuration: Optional[Union['GetPushProviderConfigurationArgs', 'GetPushProviderConfigurationArgsDict']] = None,
                      id: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPushProviderResult:
    """
    Retrieves information about an Okta Push Provider configuration. This data source allows you to fetch details about existing push providers for Apple Push Notification Service (APNS) and Firebase Cloud Messaging (FCM).

    ## Example Usage

    ### Retrieve an APNS Push Provider

    ```python
    import pulumi
    import pulumi_okta as okta

    apns_example = okta.get_push_provider(id="ppc1234567890abcdef")
    pulumi.export("apnsProviderName", apns_example.name)
    pulumi.export("apnsKeyId", apns_example.configuration.apns_configuration.key_id)
    ```

    ### Retrieve an FCM Push Provider

    ```python
    import pulumi
    import pulumi_okta as okta

    fcm_example = okta.get_push_provider(id="ppc0987654321fedcba")
    pulumi.export("fcmProviderName", fcm_example.name)
    pulumi.export("fcmProjectId", fcm_example.configuration.fcm_configuration.service_account_json.project_id)
    ```


    :param Union['GetPushProviderConfigurationArgs', 'GetPushProviderConfigurationArgsDict'] configuration: Configuration details for the push provider. The structure depends on the provider type.
    :param _builtins.str id: The unique identifier of the push provider to retrieve.
    """
    __args__ = dict()
    __args__['configuration'] = configuration
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPushProvider:getPushProvider', __args__, opts=opts, typ=GetPushProviderResult).value

    return AwaitableGetPushProviderResult(
        configuration=pulumi.get(__ret__, 'configuration'),
        id=pulumi.get(__ret__, 'id'),
        last_updated_date=pulumi.get(__ret__, 'last_updated_date'),
        name=pulumi.get(__ret__, 'name'),
        provider_type=pulumi.get(__ret__, 'provider_type'))
def get_push_provider_output(configuration: Optional[pulumi.Input[Optional[Union['GetPushProviderConfigurationArgs', 'GetPushProviderConfigurationArgsDict']]]] = None,
                             id: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPushProviderResult]:
    """
    Retrieves information about an Okta Push Provider configuration. This data source allows you to fetch details about existing push providers for Apple Push Notification Service (APNS) and Firebase Cloud Messaging (FCM).

    ## Example Usage

    ### Retrieve an APNS Push Provider

    ```python
    import pulumi
    import pulumi_okta as okta

    apns_example = okta.get_push_provider(id="ppc1234567890abcdef")
    pulumi.export("apnsProviderName", apns_example.name)
    pulumi.export("apnsKeyId", apns_example.configuration.apns_configuration.key_id)
    ```

    ### Retrieve an FCM Push Provider

    ```python
    import pulumi
    import pulumi_okta as okta

    fcm_example = okta.get_push_provider(id="ppc0987654321fedcba")
    pulumi.export("fcmProviderName", fcm_example.name)
    pulumi.export("fcmProjectId", fcm_example.configuration.fcm_configuration.service_account_json.project_id)
    ```


    :param Union['GetPushProviderConfigurationArgs', 'GetPushProviderConfigurationArgsDict'] configuration: Configuration details for the push provider. The structure depends on the provider type.
    :param _builtins.str id: The unique identifier of the push provider to retrieve.
    """
    __args__ = dict()
    __args__['configuration'] = configuration
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPushProvider:getPushProvider', __args__, opts=opts, typ=GetPushProviderResult)
    return __ret__.apply(lambda __response__: GetPushProviderResult(
        configuration=pulumi.get(__response__, 'configuration'),
        id=pulumi.get(__response__, 'id'),
        last_updated_date=pulumi.get(__response__, 'last_updated_date'),
        name=pulumi.get(__response__, 'name'),
        provider_type=pulumi.get(__response__, 'provider_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CampaignArgs', 'Campaign']

@pulumi.input_type
class CampaignArgs:
    def __init__(__self__, *,
                 campaign_tier: Optional[pulumi.Input[_builtins.str]] = None,
                 campaign_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input['CampaignNotificationSettingsArgs']] = None,
                 principal_scope_settings: Optional[pulumi.Input['CampaignPrincipalScopeSettingsArgs']] = None,
                 remediation_settings: Optional[pulumi.Input['CampaignRemediationSettingsArgs']] = None,
                 resource_settings: Optional[pulumi.Input['CampaignResourceSettingsArgs']] = None,
                 reviewer_settings: Optional[pulumi.Input['CampaignReviewerSettingsArgs']] = None,
                 schedule_settings: Optional[pulumi.Input['CampaignScheduleSettingsArgs']] = None,
                 skip_remediation: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Campaign resource.
        :param pulumi.Input[_builtins.str] campaign_tier: Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        :param pulumi.Input[_builtins.str] campaign_type: Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        :param pulumi.Input[_builtins.str] description: Human readable description.
        :param pulumi.Input[_builtins.str] name: Name of the campaign
        :param pulumi.Input['CampaignPrincipalScopeSettingsArgs'] principal_scope_settings: User scope specific settings
        :param pulumi.Input['CampaignRemediationSettingsArgs'] remediation_settings: Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        :param pulumi.Input['CampaignResourceSettingsArgs'] resource_settings: Resource specific properties.
        :param pulumi.Input['CampaignReviewerSettingsArgs'] reviewer_settings: Identifies the kind of reviewer for Access Certification.
        :param pulumi.Input['CampaignScheduleSettingsArgs'] schedule_settings: Scheduler specific settings.
        :param pulumi.Input[_builtins.bool] skip_remediation: If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        if campaign_tier is not None:
            pulumi.set(__self__, "campaign_tier", campaign_tier)
        if campaign_type is not None:
            pulumi.set(__self__, "campaign_type", campaign_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_settings is not None:
            pulumi.set(__self__, "notification_settings", notification_settings)
        if principal_scope_settings is not None:
            pulumi.set(__self__, "principal_scope_settings", principal_scope_settings)
        if remediation_settings is not None:
            pulumi.set(__self__, "remediation_settings", remediation_settings)
        if resource_settings is not None:
            pulumi.set(__self__, "resource_settings", resource_settings)
        if reviewer_settings is not None:
            pulumi.set(__self__, "reviewer_settings", reviewer_settings)
        if schedule_settings is not None:
            pulumi.set(__self__, "schedule_settings", schedule_settings)
        if skip_remediation is not None:
            pulumi.set(__self__, "skip_remediation", skip_remediation)

    @_builtins.property
    @pulumi.getter(name="campaignTier")
    def campaign_tier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        """
        return pulumi.get(self, "campaign_tier")

    @campaign_tier.setter
    def campaign_tier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "campaign_tier", value)

    @_builtins.property
    @pulumi.getter(name="campaignType")
    def campaign_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        """
        return pulumi.get(self, "campaign_type")

    @campaign_type.setter
    def campaign_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "campaign_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human readable description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the campaign
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> Optional[pulumi.Input['CampaignNotificationSettingsArgs']]:
        return pulumi.get(self, "notification_settings")

    @notification_settings.setter
    def notification_settings(self, value: Optional[pulumi.Input['CampaignNotificationSettingsArgs']]):
        pulumi.set(self, "notification_settings", value)

    @_builtins.property
    @pulumi.getter(name="principalScopeSettings")
    def principal_scope_settings(self) -> Optional[pulumi.Input['CampaignPrincipalScopeSettingsArgs']]:
        """
        User scope specific settings
        """
        return pulumi.get(self, "principal_scope_settings")

    @principal_scope_settings.setter
    def principal_scope_settings(self, value: Optional[pulumi.Input['CampaignPrincipalScopeSettingsArgs']]):
        pulumi.set(self, "principal_scope_settings", value)

    @_builtins.property
    @pulumi.getter(name="remediationSettings")
    def remediation_settings(self) -> Optional[pulumi.Input['CampaignRemediationSettingsArgs']]:
        """
        Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        """
        return pulumi.get(self, "remediation_settings")

    @remediation_settings.setter
    def remediation_settings(self, value: Optional[pulumi.Input['CampaignRemediationSettingsArgs']]):
        pulumi.set(self, "remediation_settings", value)

    @_builtins.property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> Optional[pulumi.Input['CampaignResourceSettingsArgs']]:
        """
        Resource specific properties.
        """
        return pulumi.get(self, "resource_settings")

    @resource_settings.setter
    def resource_settings(self, value: Optional[pulumi.Input['CampaignResourceSettingsArgs']]):
        pulumi.set(self, "resource_settings", value)

    @_builtins.property
    @pulumi.getter(name="reviewerSettings")
    def reviewer_settings(self) -> Optional[pulumi.Input['CampaignReviewerSettingsArgs']]:
        """
        Identifies the kind of reviewer for Access Certification.
        """
        return pulumi.get(self, "reviewer_settings")

    @reviewer_settings.setter
    def reviewer_settings(self, value: Optional[pulumi.Input['CampaignReviewerSettingsArgs']]):
        pulumi.set(self, "reviewer_settings", value)

    @_builtins.property
    @pulumi.getter(name="scheduleSettings")
    def schedule_settings(self) -> Optional[pulumi.Input['CampaignScheduleSettingsArgs']]:
        """
        Scheduler specific settings.
        """
        return pulumi.get(self, "schedule_settings")

    @schedule_settings.setter
    def schedule_settings(self, value: Optional[pulumi.Input['CampaignScheduleSettingsArgs']]):
        pulumi.set(self, "schedule_settings", value)

    @_builtins.property
    @pulumi.getter(name="skipRemediation")
    def skip_remediation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        return pulumi.get(self, "skip_remediation")

    @skip_remediation.setter
    def skip_remediation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_remediation", value)


@pulumi.input_type
class _CampaignState:
    def __init__(__self__, *,
                 campaign_tier: Optional[pulumi.Input[_builtins.str]] = None,
                 campaign_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input['CampaignNotificationSettingsArgs']] = None,
                 principal_scope_settings: Optional[pulumi.Input['CampaignPrincipalScopeSettingsArgs']] = None,
                 remediation_settings: Optional[pulumi.Input['CampaignRemediationSettingsArgs']] = None,
                 resource_settings: Optional[pulumi.Input['CampaignResourceSettingsArgs']] = None,
                 reviewer_settings: Optional[pulumi.Input['CampaignReviewerSettingsArgs']] = None,
                 schedule_settings: Optional[pulumi.Input['CampaignScheduleSettingsArgs']] = None,
                 skip_remediation: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Campaign resources.
        :param pulumi.Input[_builtins.str] campaign_tier: Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        :param pulumi.Input[_builtins.str] campaign_type: Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        :param pulumi.Input[_builtins.str] description: Human readable description.
        :param pulumi.Input[_builtins.str] name: Name of the campaign
        :param pulumi.Input['CampaignPrincipalScopeSettingsArgs'] principal_scope_settings: User scope specific settings
        :param pulumi.Input['CampaignRemediationSettingsArgs'] remediation_settings: Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        :param pulumi.Input['CampaignResourceSettingsArgs'] resource_settings: Resource specific properties.
        :param pulumi.Input['CampaignReviewerSettingsArgs'] reviewer_settings: Identifies the kind of reviewer for Access Certification.
        :param pulumi.Input['CampaignScheduleSettingsArgs'] schedule_settings: Scheduler specific settings.
        :param pulumi.Input[_builtins.bool] skip_remediation: If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        if campaign_tier is not None:
            pulumi.set(__self__, "campaign_tier", campaign_tier)
        if campaign_type is not None:
            pulumi.set(__self__, "campaign_type", campaign_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notification_settings is not None:
            pulumi.set(__self__, "notification_settings", notification_settings)
        if principal_scope_settings is not None:
            pulumi.set(__self__, "principal_scope_settings", principal_scope_settings)
        if remediation_settings is not None:
            pulumi.set(__self__, "remediation_settings", remediation_settings)
        if resource_settings is not None:
            pulumi.set(__self__, "resource_settings", resource_settings)
        if reviewer_settings is not None:
            pulumi.set(__self__, "reviewer_settings", reviewer_settings)
        if schedule_settings is not None:
            pulumi.set(__self__, "schedule_settings", schedule_settings)
        if skip_remediation is not None:
            pulumi.set(__self__, "skip_remediation", skip_remediation)

    @_builtins.property
    @pulumi.getter(name="campaignTier")
    def campaign_tier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        """
        return pulumi.get(self, "campaign_tier")

    @campaign_tier.setter
    def campaign_tier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "campaign_tier", value)

    @_builtins.property
    @pulumi.getter(name="campaignType")
    def campaign_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        """
        return pulumi.get(self, "campaign_type")

    @campaign_type.setter
    def campaign_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "campaign_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human readable description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the campaign
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> Optional[pulumi.Input['CampaignNotificationSettingsArgs']]:
        return pulumi.get(self, "notification_settings")

    @notification_settings.setter
    def notification_settings(self, value: Optional[pulumi.Input['CampaignNotificationSettingsArgs']]):
        pulumi.set(self, "notification_settings", value)

    @_builtins.property
    @pulumi.getter(name="principalScopeSettings")
    def principal_scope_settings(self) -> Optional[pulumi.Input['CampaignPrincipalScopeSettingsArgs']]:
        """
        User scope specific settings
        """
        return pulumi.get(self, "principal_scope_settings")

    @principal_scope_settings.setter
    def principal_scope_settings(self, value: Optional[pulumi.Input['CampaignPrincipalScopeSettingsArgs']]):
        pulumi.set(self, "principal_scope_settings", value)

    @_builtins.property
    @pulumi.getter(name="remediationSettings")
    def remediation_settings(self) -> Optional[pulumi.Input['CampaignRemediationSettingsArgs']]:
        """
        Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        """
        return pulumi.get(self, "remediation_settings")

    @remediation_settings.setter
    def remediation_settings(self, value: Optional[pulumi.Input['CampaignRemediationSettingsArgs']]):
        pulumi.set(self, "remediation_settings", value)

    @_builtins.property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> Optional[pulumi.Input['CampaignResourceSettingsArgs']]:
        """
        Resource specific properties.
        """
        return pulumi.get(self, "resource_settings")

    @resource_settings.setter
    def resource_settings(self, value: Optional[pulumi.Input['CampaignResourceSettingsArgs']]):
        pulumi.set(self, "resource_settings", value)

    @_builtins.property
    @pulumi.getter(name="reviewerSettings")
    def reviewer_settings(self) -> Optional[pulumi.Input['CampaignReviewerSettingsArgs']]:
        """
        Identifies the kind of reviewer for Access Certification.
        """
        return pulumi.get(self, "reviewer_settings")

    @reviewer_settings.setter
    def reviewer_settings(self, value: Optional[pulumi.Input['CampaignReviewerSettingsArgs']]):
        pulumi.set(self, "reviewer_settings", value)

    @_builtins.property
    @pulumi.getter(name="scheduleSettings")
    def schedule_settings(self) -> Optional[pulumi.Input['CampaignScheduleSettingsArgs']]:
        """
        Scheduler specific settings.
        """
        return pulumi.get(self, "schedule_settings")

    @schedule_settings.setter
    def schedule_settings(self, value: Optional[pulumi.Input['CampaignScheduleSettingsArgs']]):
        pulumi.set(self, "schedule_settings", value)

    @_builtins.property
    @pulumi.getter(name="skipRemediation")
    def skip_remediation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        return pulumi.get(self, "skip_remediation")

    @skip_remediation.setter
    def skip_remediation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_remediation", value)


@pulumi.type_token("okta:index/campaign:Campaign")
class Campaign(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 campaign_tier: Optional[pulumi.Input[_builtins.str]] = None,
                 campaign_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input[Union['CampaignNotificationSettingsArgs', 'CampaignNotificationSettingsArgsDict']]] = None,
                 principal_scope_settings: Optional[pulumi.Input[Union['CampaignPrincipalScopeSettingsArgs', 'CampaignPrincipalScopeSettingsArgsDict']]] = None,
                 remediation_settings: Optional[pulumi.Input[Union['CampaignRemediationSettingsArgs', 'CampaignRemediationSettingsArgsDict']]] = None,
                 resource_settings: Optional[pulumi.Input[Union['CampaignResourceSettingsArgs', 'CampaignResourceSettingsArgsDict']]] = None,
                 reviewer_settings: Optional[pulumi.Input[Union['CampaignReviewerSettingsArgs', 'CampaignReviewerSettingsArgsDict']]] = None,
                 schedule_settings: Optional[pulumi.Input[Union['CampaignScheduleSettingsArgs', 'CampaignScheduleSettingsArgsDict']]] = None,
                 skip_remediation: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages Campaign. This resource allows you to create and configure an Okta [Campaign](https://developer.okta.com/docs/api/iga/openapi/governance.api/tag/Campaigns/).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Campaign("example", name="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/campaign:Campaign example <campaign_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] campaign_tier: Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        :param pulumi.Input[_builtins.str] campaign_type: Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        :param pulumi.Input[_builtins.str] description: Human readable description.
        :param pulumi.Input[_builtins.str] name: Name of the campaign
        :param pulumi.Input[Union['CampaignPrincipalScopeSettingsArgs', 'CampaignPrincipalScopeSettingsArgsDict']] principal_scope_settings: User scope specific settings
        :param pulumi.Input[Union['CampaignRemediationSettingsArgs', 'CampaignRemediationSettingsArgsDict']] remediation_settings: Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        :param pulumi.Input[Union['CampaignResourceSettingsArgs', 'CampaignResourceSettingsArgsDict']] resource_settings: Resource specific properties.
        :param pulumi.Input[Union['CampaignReviewerSettingsArgs', 'CampaignReviewerSettingsArgsDict']] reviewer_settings: Identifies the kind of reviewer for Access Certification.
        :param pulumi.Input[Union['CampaignScheduleSettingsArgs', 'CampaignScheduleSettingsArgsDict']] schedule_settings: Scheduler specific settings.
        :param pulumi.Input[_builtins.bool] skip_remediation: If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CampaignArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Campaign. This resource allows you to create and configure an Okta [Campaign](https://developer.okta.com/docs/api/iga/openapi/governance.api/tag/Campaigns/).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Campaign("example", name="example")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/campaign:Campaign example <campaign_id>
        ```

        :param str resource_name: The name of the resource.
        :param CampaignArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CampaignArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 campaign_tier: Optional[pulumi.Input[_builtins.str]] = None,
                 campaign_type: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 notification_settings: Optional[pulumi.Input[Union['CampaignNotificationSettingsArgs', 'CampaignNotificationSettingsArgsDict']]] = None,
                 principal_scope_settings: Optional[pulumi.Input[Union['CampaignPrincipalScopeSettingsArgs', 'CampaignPrincipalScopeSettingsArgsDict']]] = None,
                 remediation_settings: Optional[pulumi.Input[Union['CampaignRemediationSettingsArgs', 'CampaignRemediationSettingsArgsDict']]] = None,
                 resource_settings: Optional[pulumi.Input[Union['CampaignResourceSettingsArgs', 'CampaignResourceSettingsArgsDict']]] = None,
                 reviewer_settings: Optional[pulumi.Input[Union['CampaignReviewerSettingsArgs', 'CampaignReviewerSettingsArgsDict']]] = None,
                 schedule_settings: Optional[pulumi.Input[Union['CampaignScheduleSettingsArgs', 'CampaignScheduleSettingsArgsDict']]] = None,
                 skip_remediation: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CampaignArgs.__new__(CampaignArgs)

            __props__.__dict__["campaign_tier"] = campaign_tier
            __props__.__dict__["campaign_type"] = campaign_type
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["notification_settings"] = notification_settings
            __props__.__dict__["principal_scope_settings"] = principal_scope_settings
            __props__.__dict__["remediation_settings"] = remediation_settings
            __props__.__dict__["resource_settings"] = resource_settings
            __props__.__dict__["reviewer_settings"] = reviewer_settings
            __props__.__dict__["schedule_settings"] = schedule_settings
            __props__.__dict__["skip_remediation"] = skip_remediation
        super(Campaign, __self__).__init__(
            'okta:index/campaign:Campaign',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            campaign_tier: Optional[pulumi.Input[_builtins.str]] = None,
            campaign_type: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            notification_settings: Optional[pulumi.Input[Union['CampaignNotificationSettingsArgs', 'CampaignNotificationSettingsArgsDict']]] = None,
            principal_scope_settings: Optional[pulumi.Input[Union['CampaignPrincipalScopeSettingsArgs', 'CampaignPrincipalScopeSettingsArgsDict']]] = None,
            remediation_settings: Optional[pulumi.Input[Union['CampaignRemediationSettingsArgs', 'CampaignRemediationSettingsArgsDict']]] = None,
            resource_settings: Optional[pulumi.Input[Union['CampaignResourceSettingsArgs', 'CampaignResourceSettingsArgsDict']]] = None,
            reviewer_settings: Optional[pulumi.Input[Union['CampaignReviewerSettingsArgs', 'CampaignReviewerSettingsArgsDict']]] = None,
            schedule_settings: Optional[pulumi.Input[Union['CampaignScheduleSettingsArgs', 'CampaignScheduleSettingsArgsDict']]] = None,
            skip_remediation: Optional[pulumi.Input[_builtins.bool]] = None) -> 'Campaign':
        """
        Get an existing Campaign resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] campaign_tier: Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        :param pulumi.Input[_builtins.str] campaign_type: Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        :param pulumi.Input[_builtins.str] description: Human readable description.
        :param pulumi.Input[_builtins.str] name: Name of the campaign
        :param pulumi.Input[Union['CampaignPrincipalScopeSettingsArgs', 'CampaignPrincipalScopeSettingsArgsDict']] principal_scope_settings: User scope specific settings
        :param pulumi.Input[Union['CampaignRemediationSettingsArgs', 'CampaignRemediationSettingsArgsDict']] remediation_settings: Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        :param pulumi.Input[Union['CampaignResourceSettingsArgs', 'CampaignResourceSettingsArgsDict']] resource_settings: Resource specific properties.
        :param pulumi.Input[Union['CampaignReviewerSettingsArgs', 'CampaignReviewerSettingsArgsDict']] reviewer_settings: Identifies the kind of reviewer for Access Certification.
        :param pulumi.Input[Union['CampaignScheduleSettingsArgs', 'CampaignScheduleSettingsArgsDict']] schedule_settings: Scheduler specific settings.
        :param pulumi.Input[_builtins.bool] skip_remediation: If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CampaignState.__new__(_CampaignState)

        __props__.__dict__["campaign_tier"] = campaign_tier
        __props__.__dict__["campaign_type"] = campaign_type
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["notification_settings"] = notification_settings
        __props__.__dict__["principal_scope_settings"] = principal_scope_settings
        __props__.__dict__["remediation_settings"] = remediation_settings
        __props__.__dict__["resource_settings"] = resource_settings
        __props__.__dict__["reviewer_settings"] = reviewer_settings
        __props__.__dict__["schedule_settings"] = schedule_settings
        __props__.__dict__["skip_remediation"] = skip_remediation
        return Campaign(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="campaignTier")
    def campaign_tier(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Indicates the minimum required SKU to manage the campaign. Enum: "BASIC", "PREMIUM".
        """
        return pulumi.get(self, "campaign_tier")

    @_builtins.property
    @pulumi.getter(name="campaignType")
    def campaign_type(self) -> pulumi.Output[_builtins.str]:
        """
        Identifies if it is a resource campaign or a user campaign. By default, it is "RESOURCE". Enum: "RESOURCE", "USER".
        """
        return pulumi.get(self, "campaign_type")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Human readable description.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the campaign
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="notificationSettings")
    def notification_settings(self) -> pulumi.Output[Optional['outputs.CampaignNotificationSettings']]:
        return pulumi.get(self, "notification_settings")

    @_builtins.property
    @pulumi.getter(name="principalScopeSettings")
    def principal_scope_settings(self) -> pulumi.Output[Optional['outputs.CampaignPrincipalScopeSettings']]:
        """
        User scope specific settings
        """
        return pulumi.get(self, "principal_scope_settings")

    @_builtins.property
    @pulumi.getter(name="remediationSettings")
    def remediation_settings(self) -> pulumi.Output[Optional['outputs.CampaignRemediationSettings']]:
        """
        Specify the action to be taken after a reviewer makes a decision to APPROVE or REVOKE the access, or if the campaign was CLOSED and there was no response from the reviewer.
        """
        return pulumi.get(self, "remediation_settings")

    @_builtins.property
    @pulumi.getter(name="resourceSettings")
    def resource_settings(self) -> pulumi.Output[Optional['outputs.CampaignResourceSettings']]:
        """
        Resource specific properties.
        """
        return pulumi.get(self, "resource_settings")

    @_builtins.property
    @pulumi.getter(name="reviewerSettings")
    def reviewer_settings(self) -> pulumi.Output[Optional['outputs.CampaignReviewerSettings']]:
        """
        Identifies the kind of reviewer for Access Certification.
        """
        return pulumi.get(self, "reviewer_settings")

    @_builtins.property
    @pulumi.getter(name="scheduleSettings")
    def schedule_settings(self) -> pulumi.Output[Optional['outputs.CampaignScheduleSettings']]:
        """
        Scheduler specific settings.
        """
        return pulumi.get(self, "schedule_settings")

    @_builtins.property
    @pulumi.getter(name="skipRemediation")
    def skip_remediation(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If true, skip remediation when ending the campaign (only applicable if remediationSetting.noResponse=DENY).
        """
        return pulumi.get(self, "skip_remediation")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDefaultSigninPageResult',
    'AwaitableGetDefaultSigninPageResult',
    'get_default_signin_page',
    'get_default_signin_page_output',
]

@pulumi.output_type
class GetDefaultSigninPageResult:
    """
    A collection of values returned by getDefaultSigninPage.
    """
    def __init__(__self__, brand_id=None, content_security_policy_setting=None, id=None, page_content=None, widget_customizations=None, widget_version=None):
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if content_security_policy_setting and not isinstance(content_security_policy_setting, dict):
            raise TypeError("Expected argument 'content_security_policy_setting' to be a dict")
        pulumi.set(__self__, "content_security_policy_setting", content_security_policy_setting)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_content and not isinstance(page_content, str):
            raise TypeError("Expected argument 'page_content' to be a str")
        pulumi.set(__self__, "page_content", page_content)
        if widget_customizations and not isinstance(widget_customizations, dict):
            raise TypeError("Expected argument 'widget_customizations' to be a dict")
        pulumi.set(__self__, "widget_customizations", widget_customizations)
        if widget_version and not isinstance(widget_version, str):
            raise TypeError("Expected argument 'widget_version' to be a str")
        pulumi.set(__self__, "widget_version", widget_version)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> _builtins.str:
        """
        brand id of the preview signin page
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="contentSecurityPolicySetting")
    def content_security_policy_setting(self) -> Optional['outputs.GetDefaultSigninPageContentSecurityPolicySettingResult']:
        return pulumi.get(self, "content_security_policy_setting")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        placeholder id
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageContent")
    def page_content(self) -> _builtins.str:
        """
        page content of the preview signin page
        """
        return pulumi.get(self, "page_content")

    @_builtins.property
    @pulumi.getter(name="widgetCustomizations")
    def widget_customizations(self) -> Optional['outputs.GetDefaultSigninPageWidgetCustomizationsResult']:
        return pulumi.get(self, "widget_customizations")

    @_builtins.property
    @pulumi.getter(name="widgetVersion")
    def widget_version(self) -> _builtins.str:
        """
        widget version specified as a Semver
        """
        return pulumi.get(self, "widget_version")


class AwaitableGetDefaultSigninPageResult(GetDefaultSigninPageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDefaultSigninPageResult(
            brand_id=self.brand_id,
            content_security_policy_setting=self.content_security_policy_setting,
            id=self.id,
            page_content=self.page_content,
            widget_customizations=self.widget_customizations,
            widget_version=self.widget_version)


def get_default_signin_page(brand_id: Optional[_builtins.str] = None,
                            content_security_policy_setting: Optional[Union['GetDefaultSigninPageContentSecurityPolicySettingArgs', 'GetDefaultSigninPageContentSecurityPolicySettingArgsDict']] = None,
                            widget_customizations: Optional[Union['GetDefaultSigninPageWidgetCustomizationsArgs', 'GetDefaultSigninPageWidgetCustomizationsArgsDict']] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDefaultSigninPageResult:
    """
    Retrieve the default signin page of a brand


    :param _builtins.str brand_id: brand id of the preview signin page
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['contentSecurityPolicySetting'] = content_security_policy_setting
    __args__['widgetCustomizations'] = widget_customizations
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getDefaultSigninPage:getDefaultSigninPage', __args__, opts=opts, typ=GetDefaultSigninPageResult).value

    return AwaitableGetDefaultSigninPageResult(
        brand_id=pulumi.get(__ret__, 'brand_id'),
        content_security_policy_setting=pulumi.get(__ret__, 'content_security_policy_setting'),
        id=pulumi.get(__ret__, 'id'),
        page_content=pulumi.get(__ret__, 'page_content'),
        widget_customizations=pulumi.get(__ret__, 'widget_customizations'),
        widget_version=pulumi.get(__ret__, 'widget_version'))
def get_default_signin_page_output(brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   content_security_policy_setting: Optional[pulumi.Input[Optional[Union['GetDefaultSigninPageContentSecurityPolicySettingArgs', 'GetDefaultSigninPageContentSecurityPolicySettingArgsDict']]]] = None,
                                   widget_customizations: Optional[pulumi.Input[Optional[Union['GetDefaultSigninPageWidgetCustomizationsArgs', 'GetDefaultSigninPageWidgetCustomizationsArgsDict']]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDefaultSigninPageResult]:
    """
    Retrieve the default signin page of a brand


    :param _builtins.str brand_id: brand id of the preview signin page
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['contentSecurityPolicySetting'] = content_security_policy_setting
    __args__['widgetCustomizations'] = widget_customizations
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getDefaultSigninPage:getDefaultSigninPage', __args__, opts=opts, typ=GetDefaultSigninPageResult)
    return __ret__.apply(lambda __response__: GetDefaultSigninPageResult(
        brand_id=pulumi.get(__response__, 'brand_id'),
        content_security_policy_setting=pulumi.get(__response__, 'content_security_policy_setting'),
        id=pulumi.get(__response__, 'id'),
        page_content=pulumi.get(__response__, 'page_content'),
        widget_customizations=pulumi.get(__response__, 'widget_customizations'),
        widget_version=pulumi.get(__response__, 'widget_version')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RequestConditionArgs', 'RequestCondition']

@pulumi.input_type
class RequestConditionArgs:
    def __init__(__self__, *,
                 approval_sequence_id: pulumi.Input[_builtins.str],
                 resource_id: pulumi.Input[_builtins.str],
                 access_duration_settings: Optional[pulumi.Input['RequestConditionAccessDurationSettingsArgs']] = None,
                 access_scope_settings: Optional[pulumi.Input['RequestConditionAccessScopeSettingsArgs']] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 requester_settings: Optional[pulumi.Input['RequestConditionRequesterSettingsArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RequestCondition resource.
        :param pulumi.Input[_builtins.str] approval_sequence_id: The ID of the approval sequence.
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        :param pulumi.Input['RequestConditionAccessDurationSettingsArgs'] access_duration_settings: The access duration settings for the request condition
        :param pulumi.Input[_builtins.str] description: The description of the request condition.
        :param pulumi.Input[_builtins.str] name: The name of the request condition.
        :param pulumi.Input[_builtins.int] priority: The priority of the request condition. Lower numbers indicate higher priority.
        :param pulumi.Input[_builtins.str] status: Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        pulumi.set(__self__, "approval_sequence_id", approval_sequence_id)
        pulumi.set(__self__, "resource_id", resource_id)
        if access_duration_settings is not None:
            pulumi.set(__self__, "access_duration_settings", access_duration_settings)
        if access_scope_settings is not None:
            pulumi.set(__self__, "access_scope_settings", access_scope_settings)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if requester_settings is not None:
            pulumi.set(__self__, "requester_settings", requester_settings)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="approvalSequenceId")
    def approval_sequence_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the approval sequence.
        """
        return pulumi.get(self, "approval_sequence_id")

    @approval_sequence_id.setter
    def approval_sequence_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "approval_sequence_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_id", value)

    @_builtins.property
    @pulumi.getter(name="accessDurationSettings")
    def access_duration_settings(self) -> Optional[pulumi.Input['RequestConditionAccessDurationSettingsArgs']]:
        """
        The access duration settings for the request condition
        """
        return pulumi.get(self, "access_duration_settings")

    @access_duration_settings.setter
    def access_duration_settings(self, value: Optional[pulumi.Input['RequestConditionAccessDurationSettingsArgs']]):
        pulumi.set(self, "access_duration_settings", value)

    @_builtins.property
    @pulumi.getter(name="accessScopeSettings")
    def access_scope_settings(self) -> Optional[pulumi.Input['RequestConditionAccessScopeSettingsArgs']]:
        return pulumi.get(self, "access_scope_settings")

    @access_scope_settings.setter
    def access_scope_settings(self, value: Optional[pulumi.Input['RequestConditionAccessScopeSettingsArgs']]):
        pulumi.set(self, "access_scope_settings", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the request condition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the request condition.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The priority of the request condition. Lower numbers indicate higher priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter(name="requesterSettings")
    def requester_settings(self) -> Optional[pulumi.Input['RequestConditionRequesterSettingsArgs']]:
        return pulumi.get(self, "requester_settings")

    @requester_settings.setter
    def requester_settings(self, value: Optional[pulumi.Input['RequestConditionRequesterSettingsArgs']]):
        pulumi.set(self, "requester_settings", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _RequestConditionState:
    def __init__(__self__, *,
                 access_duration_settings: Optional[pulumi.Input['RequestConditionAccessDurationSettingsArgs']] = None,
                 access_scope_settings: Optional[pulumi.Input['RequestConditionAccessScopeSettingsArgs']] = None,
                 approval_sequence_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created: Optional[pulumi.Input[_builtins.str]] = None,
                 created_by: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated: Optional[pulumi.Input[_builtins.str]] = None,
                 last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 requester_settings: Optional[pulumi.Input['RequestConditionRequesterSettingsArgs']] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RequestCondition resources.
        :param pulumi.Input['RequestConditionAccessDurationSettingsArgs'] access_duration_settings: The access duration settings for the request condition
        :param pulumi.Input[_builtins.str] approval_sequence_id: The ID of the approval sequence.
        :param pulumi.Input[_builtins.str] created: The date and time when the request condition was created.
        :param pulumi.Input[_builtins.str] created_by: The id of the user who created the request condition.
        :param pulumi.Input[_builtins.str] description: The description of the request condition.
        :param pulumi.Input[_builtins.str] last_updated: The date and time when the request condition was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The id of the user who last updated the request condition.
        :param pulumi.Input[_builtins.str] name: The name of the request condition.
        :param pulumi.Input[_builtins.int] priority: The priority of the request condition. Lower numbers indicate higher priority.
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        :param pulumi.Input[_builtins.str] status: Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        if access_duration_settings is not None:
            pulumi.set(__self__, "access_duration_settings", access_duration_settings)
        if access_scope_settings is not None:
            pulumi.set(__self__, "access_scope_settings", access_scope_settings)
        if approval_sequence_id is not None:
            pulumi.set(__self__, "approval_sequence_id", approval_sequence_id)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if last_updated is not None:
            pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by is not None:
            pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if requester_settings is not None:
            pulumi.set(__self__, "requester_settings", requester_settings)
        if resource_id is not None:
            pulumi.set(__self__, "resource_id", resource_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="accessDurationSettings")
    def access_duration_settings(self) -> Optional[pulumi.Input['RequestConditionAccessDurationSettingsArgs']]:
        """
        The access duration settings for the request condition
        """
        return pulumi.get(self, "access_duration_settings")

    @access_duration_settings.setter
    def access_duration_settings(self, value: Optional[pulumi.Input['RequestConditionAccessDurationSettingsArgs']]):
        pulumi.set(self, "access_duration_settings", value)

    @_builtins.property
    @pulumi.getter(name="accessScopeSettings")
    def access_scope_settings(self) -> Optional[pulumi.Input['RequestConditionAccessScopeSettingsArgs']]:
        return pulumi.get(self, "access_scope_settings")

    @access_scope_settings.setter
    def access_scope_settings(self, value: Optional[pulumi.Input['RequestConditionAccessScopeSettingsArgs']]):
        pulumi.set(self, "access_scope_settings", value)

    @_builtins.property
    @pulumi.getter(name="approvalSequenceId")
    def approval_sequence_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the approval sequence.
        """
        return pulumi.get(self, "approval_sequence_id")

    @approval_sequence_id.setter
    def approval_sequence_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "approval_sequence_id", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the request condition was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the user who created the request condition.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the request condition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the request condition was last updated.
        """
        return pulumi.get(self, "last_updated")

    @last_updated.setter
    def last_updated(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the user who last updated the request condition.
        """
        return pulumi.get(self, "last_updated_by")

    @last_updated_by.setter
    def last_updated_by(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_by", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the request condition.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The priority of the request condition. Lower numbers indicate higher priority.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter(name="requesterSettings")
    def requester_settings(self) -> Optional[pulumi.Input['RequestConditionRequesterSettingsArgs']]:
        return pulumi.get(self, "requester_settings")

    @requester_settings.setter
    def requester_settings(self, value: Optional[pulumi.Input['RequestConditionRequesterSettingsArgs']]):
        pulumi.set(self, "requester_settings", value)

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")

    @resource_id.setter
    def resource_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("okta:index/requestCondition:RequestCondition")
class RequestCondition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_duration_settings: Optional[pulumi.Input[Union['RequestConditionAccessDurationSettingsArgs', 'RequestConditionAccessDurationSettingsArgsDict']]] = None,
                 access_scope_settings: Optional[pulumi.Input[Union['RequestConditionAccessScopeSettingsArgs', 'RequestConditionAccessScopeSettingsArgsDict']]] = None,
                 approval_sequence_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 requester_settings: Optional[pulumi.Input[Union['RequestConditionRequesterSettingsArgs', 'RequestConditionRequesterSettingsArgsDict']]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages request conditions. This resource allows you to create and configure an Okta [request-condition](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Conditions/#tag/Request-Conditions).

        ## Example Usage

        ### Basic Example

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RequestCondition("example",
            resource_id="<resource_id>",
            approval_sequence_id="<approval_sequence_id>",
            name="<name>",
            access_scope_settings={
                "type": "RESOURCE_DEFAULT",
            },
            requester_settings={
                "type": "EVERYONE",
            })
        ```

        ### Example with Active Status

        ```python
        import pulumi
        import pulumi_okta as okta

        example_active = okta.RequestCondition("example_active",
            status="ACTIVE",
            resource_id="<resource_id>",
            approval_sequence_id="<approval_sequence_id>",
            name="<name>",
            access_scope_settings={
                "type": "RESOURCE_DEFAULT",
            },
            requester_settings={
                "type": "EVERYONE",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestCondition:RequestCondition example <resource_id>/<request_condition_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RequestConditionAccessDurationSettingsArgs', 'RequestConditionAccessDurationSettingsArgsDict']] access_duration_settings: The access duration settings for the request condition
        :param pulumi.Input[_builtins.str] approval_sequence_id: The ID of the approval sequence.
        :param pulumi.Input[_builtins.str] description: The description of the request condition.
        :param pulumi.Input[_builtins.str] name: The name of the request condition.
        :param pulumi.Input[_builtins.int] priority: The priority of the request condition. Lower numbers indicate higher priority.
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        :param pulumi.Input[_builtins.str] status: Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RequestConditionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages request conditions. This resource allows you to create and configure an Okta [request-condition](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Conditions/#tag/Request-Conditions).

        ## Example Usage

        ### Basic Example

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RequestCondition("example",
            resource_id="<resource_id>",
            approval_sequence_id="<approval_sequence_id>",
            name="<name>",
            access_scope_settings={
                "type": "RESOURCE_DEFAULT",
            },
            requester_settings={
                "type": "EVERYONE",
            })
        ```

        ### Example with Active Status

        ```python
        import pulumi
        import pulumi_okta as okta

        example_active = okta.RequestCondition("example_active",
            status="ACTIVE",
            resource_id="<resource_id>",
            approval_sequence_id="<approval_sequence_id>",
            name="<name>",
            access_scope_settings={
                "type": "RESOURCE_DEFAULT",
            },
            requester_settings={
                "type": "EVERYONE",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestCondition:RequestCondition example <resource_id>/<request_condition_id>
        ```

        :param str resource_name: The name of the resource.
        :param RequestConditionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RequestConditionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_duration_settings: Optional[pulumi.Input[Union['RequestConditionAccessDurationSettingsArgs', 'RequestConditionAccessDurationSettingsArgsDict']]] = None,
                 access_scope_settings: Optional[pulumi.Input[Union['RequestConditionAccessScopeSettingsArgs', 'RequestConditionAccessScopeSettingsArgsDict']]] = None,
                 approval_sequence_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 requester_settings: Optional[pulumi.Input[Union['RequestConditionRequesterSettingsArgs', 'RequestConditionRequesterSettingsArgsDict']]] = None,
                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RequestConditionArgs.__new__(RequestConditionArgs)

            __props__.__dict__["access_duration_settings"] = access_duration_settings
            __props__.__dict__["access_scope_settings"] = access_scope_settings
            if approval_sequence_id is None and not opts.urn:
                raise TypeError("Missing required property 'approval_sequence_id'")
            __props__.__dict__["approval_sequence_id"] = approval_sequence_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["priority"] = priority
            __props__.__dict__["requester_settings"] = requester_settings
            if resource_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_id'")
            __props__.__dict__["resource_id"] = resource_id
            __props__.__dict__["status"] = status
            __props__.__dict__["created"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["last_updated"] = None
            __props__.__dict__["last_updated_by"] = None
        super(RequestCondition, __self__).__init__(
            'okta:index/requestCondition:RequestCondition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_duration_settings: Optional[pulumi.Input[Union['RequestConditionAccessDurationSettingsArgs', 'RequestConditionAccessDurationSettingsArgsDict']]] = None,
            access_scope_settings: Optional[pulumi.Input[Union['RequestConditionAccessScopeSettingsArgs', 'RequestConditionAccessScopeSettingsArgsDict']]] = None,
            approval_sequence_id: Optional[pulumi.Input[_builtins.str]] = None,
            created: Optional[pulumi.Input[_builtins.str]] = None,
            created_by: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated: Optional[pulumi.Input[_builtins.str]] = None,
            last_updated_by: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            requester_settings: Optional[pulumi.Input[Union['RequestConditionRequesterSettingsArgs', 'RequestConditionRequesterSettingsArgsDict']]] = None,
            resource_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'RequestCondition':
        """
        Get an existing RequestCondition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RequestConditionAccessDurationSettingsArgs', 'RequestConditionAccessDurationSettingsArgsDict']] access_duration_settings: The access duration settings for the request condition
        :param pulumi.Input[_builtins.str] approval_sequence_id: The ID of the approval sequence.
        :param pulumi.Input[_builtins.str] created: The date and time when the request condition was created.
        :param pulumi.Input[_builtins.str] created_by: The id of the user who created the request condition.
        :param pulumi.Input[_builtins.str] description: The description of the request condition.
        :param pulumi.Input[_builtins.str] last_updated: The date and time when the request condition was last updated.
        :param pulumi.Input[_builtins.str] last_updated_by: The id of the user who last updated the request condition.
        :param pulumi.Input[_builtins.str] name: The name of the request condition.
        :param pulumi.Input[_builtins.int] priority: The priority of the request condition. Lower numbers indicate higher priority.
        :param pulumi.Input[_builtins.str] resource_id: The id of the resource in Okta ID format.
        :param pulumi.Input[_builtins.str] status: Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RequestConditionState.__new__(_RequestConditionState)

        __props__.__dict__["access_duration_settings"] = access_duration_settings
        __props__.__dict__["access_scope_settings"] = access_scope_settings
        __props__.__dict__["approval_sequence_id"] = approval_sequence_id
        __props__.__dict__["created"] = created
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["last_updated"] = last_updated
        __props__.__dict__["last_updated_by"] = last_updated_by
        __props__.__dict__["name"] = name
        __props__.__dict__["priority"] = priority
        __props__.__dict__["requester_settings"] = requester_settings
        __props__.__dict__["resource_id"] = resource_id
        __props__.__dict__["status"] = status
        return RequestCondition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessDurationSettings")
    def access_duration_settings(self) -> pulumi.Output[Optional['outputs.RequestConditionAccessDurationSettings']]:
        """
        The access duration settings for the request condition
        """
        return pulumi.get(self, "access_duration_settings")

    @_builtins.property
    @pulumi.getter(name="accessScopeSettings")
    def access_scope_settings(self) -> pulumi.Output[Optional['outputs.RequestConditionAccessScopeSettings']]:
        return pulumi.get(self, "access_scope_settings")

    @_builtins.property
    @pulumi.getter(name="approvalSequenceId")
    def approval_sequence_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the approval sequence.
        """
        return pulumi.get(self, "approval_sequence_id")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the request condition was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the user who created the request condition.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the request condition.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the request condition was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the user who last updated the request condition.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the request condition.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[_builtins.int]:
        """
        The priority of the request condition. Lower numbers indicate higher priority.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter(name="requesterSettings")
    def requester_settings(self) -> pulumi.Output[Optional['outputs.RequestConditionRequesterSettings']]:
        return pulumi.get(self, "requester_settings")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the condition. Valid values: `ACTIVE`, `INACTIVE`. Default is `INACTIVE`. Note: `DELETED` and `INVALID` statuses are system-managed and cannot be set directly.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDeviceResult',
    'AwaitableGetDeviceResult',
    'get_device',
    'get_device_output',
]

@pulumi.output_type
class GetDeviceResult:
    """
    A collection of values returned by getDevice.
    """
    def __init__(__self__, created=None, id=None, last_updated=None, profile=None, resource_alternate_id=None, resource_display_name=None, resource_id=None, resource_type=None, status=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if profile and not isinstance(profile, dict):
            raise TypeError("Expected argument 'profile' to be a dict")
        pulumi.set(__self__, "profile", profile)
        if resource_alternate_id and not isinstance(resource_alternate_id, str):
            raise TypeError("Expected argument 'resource_alternate_id' to be a str")
        pulumi.set(__self__, "resource_alternate_id", resource_alternate_id)
        if resource_display_name and not isinstance(resource_display_name, dict):
            raise TypeError("Expected argument 'resource_display_name' to be a dict")
        pulumi.set(__self__, "resource_display_name", resource_display_name)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if resource_type and not isinstance(resource_type, str):
            raise TypeError("Expected argument 'resource_type' to be a str")
        pulumi.set(__self__, "resource_type", resource_type)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        The creation timestamp of the device.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the device.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        The last updated timestamp of the device.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter
    def profile(self) -> Optional['outputs.GetDeviceProfileResult']:
        return pulumi.get(self, "profile")

    @_builtins.property
    @pulumi.getter(name="resourceAlternateId")
    def resource_alternate_id(self) -> _builtins.str:
        """
        The alternate ID of the device resource.
        """
        return pulumi.get(self, "resource_alternate_id")

    @_builtins.property
    @pulumi.getter(name="resourceDisplayName")
    def resource_display_name(self) -> Optional['outputs.GetDeviceResourceDisplayNameResult']:
        return pulumi.get(self, "resource_display_name")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> _builtins.str:
        """
        Alternate key for the id.
        """
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter(name="resourceType")
    def resource_type(self) -> _builtins.str:
        """
        The resource type of the device.
        """
        return pulumi.get(self, "resource_type")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the device.
        """
        return pulumi.get(self, "status")


class AwaitableGetDeviceResult(GetDeviceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeviceResult(
            created=self.created,
            id=self.id,
            last_updated=self.last_updated,
            profile=self.profile,
            resource_alternate_id=self.resource_alternate_id,
            resource_display_name=self.resource_display_name,
            resource_id=self.resource_id,
            resource_type=self.resource_type,
            status=self.status)


def get_device(id: Optional[_builtins.str] = None,
               profile: Optional[Union['GetDeviceProfileArgs', 'GetDeviceProfileArgsDict']] = None,
               resource_display_name: Optional[Union['GetDeviceResourceDisplayNameArgs', 'GetDeviceResourceDisplayNameArgsDict']] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeviceResult:
    """
    Get information about a device in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_device(id="<device_id>")
    ```


    :param _builtins.str id: The ID of the device.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['profile'] = profile
    __args__['resourceDisplayName'] = resource_display_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getDevice:getDevice', __args__, opts=opts, typ=GetDeviceResult).value

    return AwaitableGetDeviceResult(
        created=pulumi.get(__ret__, 'created'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        profile=pulumi.get(__ret__, 'profile'),
        resource_alternate_id=pulumi.get(__ret__, 'resource_alternate_id'),
        resource_display_name=pulumi.get(__ret__, 'resource_display_name'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        resource_type=pulumi.get(__ret__, 'resource_type'),
        status=pulumi.get(__ret__, 'status'))
def get_device_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                      profile: Optional[pulumi.Input[Optional[Union['GetDeviceProfileArgs', 'GetDeviceProfileArgsDict']]]] = None,
                      resource_display_name: Optional[pulumi.Input[Optional[Union['GetDeviceResourceDisplayNameArgs', 'GetDeviceResourceDisplayNameArgsDict']]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDeviceResult]:
    """
    Get information about a device in Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_device(id="<device_id>")
    ```


    :param _builtins.str id: The ID of the device.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['profile'] = profile
    __args__['resourceDisplayName'] = resource_display_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getDevice:getDevice', __args__, opts=opts, typ=GetDeviceResult)
    return __ret__.apply(lambda __response__: GetDeviceResult(
        created=pulumi.get(__response__, 'created'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        profile=pulumi.get(__response__, 'profile'),
        resource_alternate_id=pulumi.get(__response__, 'resource_alternate_id'),
        resource_display_name=pulumi.get(__response__, 'resource_display_name'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        resource_type=pulumi.get(__response__, 'resource_type'),
        status=pulumi.get(__response__, 'status')))
